@@ -1486,6 +1486,10 @@ xfce_appfinder_model_collect_item (const gchar    *desktop_id,
   item = g_hash_table_lookup (context->desktop_ids, desktop_id);
   if (G_LIKELY (item == NULL))
     {
+      /* ignore menu items without name */
+      if (garcon_menu_item_get_name (menu_item) == NULL)
+        return;
+
       item = xfce_appfinder_model_item_new (menu_item);
 
       item->categories = g_ptr_array_new_with_free_func (g_object_unref);
@@ -2246,8 +2250,7 @@ xfce_appfinder_model_save_command (XfceAppfinderModel  *model,
   appfinder_return_val_if_fail (XFCE_IS_APPFINDER_MODEL (model), FALSE);
   appfinder_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
-  if (!IS_STRING (command)
-      || g_hash_table_lookup (model->items_hash, command) != NULL)
+  if (!IS_STRING (command))
     return TRUE;
 
   /* add command to the model */
