@@ -154,8 +154,6 @@ struct _XfceAppfinderWindow
   GtkWidget                  *bbox;
   GtkWidget                  *button_launch;
   GtkWidget                  *button_preferences;
-  GtkWidget                  *bin_collapsed;
-  GtkWidget                  *bin_expanded;
 
   GarconMenuDirectory        *filter_category;
   gchar                      *filter_text;
@@ -199,7 +197,7 @@ xfce_appfinder_window_class_init (XfceAppfinderWindowClass *klass)
 static void
 xfce_appfinder_window_init (XfceAppfinderWindow *window)
 {
-  GtkWidget          *vbox, *vbox2;
+  GtkWidget          *vbox;
   GtkWidget          *entry;
   GtkWidget          *pane;
   GtkWidget          *scroll;
@@ -250,14 +248,12 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   gtk_widget_set_halign(image, GTK_ALIGN_CENTER);
   gtk_container_add (GTK_CONTAINER (hbox), image);
   gtk_widget_show (image);
-
-  vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_pack_start (GTK_BOX (hbox), vbox2, TRUE, TRUE, 0);
-  gtk_widget_show (vbox2);
   
   window->entry = entry = gtk_entry_new ();
   gtk_widget_set_halign(entry, GTK_ALIGN_FILL);
-  gtk_container_add (GTK_CONTAINER (vbox2), entry);
+  gtk_widget_set_valign (entry, GTK_ALIGN_CENTER);
+  gtk_widget_set_hexpand (entry, TRUE);
+  gtk_container_add (GTK_CONTAINER (hbox), entry);
   g_signal_connect (G_OBJECT (entry), "icon-release",
       G_CALLBACK (xfce_appfinder_window_entry_icon_released), window);
   g_signal_connect (G_OBJECT (entry), "realize",
@@ -284,11 +280,6 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   gtk_entry_completion_set_popup_single_match (completion, TRUE);
   gtk_entry_completion_set_inline_completion (completion, TRUE);
 
-  window->bin_collapsed = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
-  gtk_box_pack_start (GTK_BOX (vbox2), window->bin_collapsed, FALSE, TRUE, 0);
-  gtk_widget_show (window->bin_collapsed);
-
-
   window->paned = pane = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
   gtk_box_pack_start (GTK_BOX (vbox), pane, TRUE, TRUE, 0);
   integer = xfconf_channel_get_int (window->channel, "/last/pane-position", DEFAULT_PANED_POSITION);
@@ -345,11 +336,8 @@ xfce_appfinder_window_init (XfceAppfinderWindow *window)
   /* set the icon or tree view */
   xfce_appfinder_window_view (window);
 
-  window->bin_expanded = gtk_paned_new(GTK_ORIENTATION_HORIZONTAL);
-  gtk_box_pack_start (GTK_BOX (vbox), window->bin_expanded, FALSE, TRUE, 0);
-  gtk_widget_show (window->bin_expanded);
-
   window->bbox = hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+  gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show (hbox);
 
   window->button_preferences = button = gtk_button_new_with_mnemonic (_("_Preferences"));
@@ -565,7 +553,8 @@ xfce_appfinder_window_window_state_event (GtkWidget           *widget,
 static void
 xfce_appfinder_window_set_item_width (XfceAppfinderWindow *window)
 {
-  gint                   width = 0;
+  gint                   width = 0, padding = 0;
+  gint                   text_column_idx, column_idx = 0;
   XfceAppfinderIconSize  icon_size;
   GtkOrientation         item_orientation = GTK_ORIENTATION_VERTICAL;
   GList                 *renderers;
@@ -579,30 +568,37 @@ xfce_appfinder_window_set_item_width (XfceAppfinderWindow *window)
   switch (icon_size)
     {
     case XFCE_APPFINDER_ICON_SIZE_SMALLEST:
+      padding = 2;
       width = 16 * 3.75;
       break;
 
     case XFCE_APPFINDER_ICON_SIZE_SMALLER:
+      padding = 2;
       width = 24 * 3;
       break;
 
     case XFCE_APPFINDER_ICON_SIZE_SMALL:
+      padding = 4;
       width = 36 * 2.5;
       break;
 
     case XFCE_APPFINDER_ICON_SIZE_NORMAL:
+      padding = 4;
       width = 48 * 2;
       break;
 
     case XFCE_APPFINDER_ICON_SIZE_LARGE:
+      padding = 6;
       width = 64 * 1.5;
       break;
 
     case XFCE_APPFINDER_ICON_SIZE_LARGER:
+      padding = 6;
       width = 96 * 1.75;
       break;
 
     case XFCE_APPFINDER_ICON_SIZE_LARGEST:
+      padding = 6;
       width = 128 * 1.25;
       break;
     }
@@ -614,16 +610,26 @@ xfce_appfinder_window_set_item_width (XfceAppfinderWindow *window)
     }
 
   gtk_icon_view_set_item_orientation (GTK_ICON_VIEW (window->view), item_orientation);
+  gtk_icon_view_set_item_padding (GTK_ICON_VIEW (window->view), padding);
   gtk_icon_view_set_item_width (GTK_ICON_VIEW (window->view), width);
 
-  if (item_orientation == GTK_ORIENTATION_HORIZONTAL)
-    {
-      /* work around the yalign = 0.0 gtk uses */
-      renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (window->view));
-      for (li = renderers; li != NULL; li = li->next)
-        g_object_set (li->data, "yalign", 0.5, NULL);
-      g_list_free (renderers);
+  renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (window->view));
+  text_column_idx = gtk_icon_view_get_text_column (GTK_ICON_VIEW (window->view));
+
+  for (li = renderers; li != NULL; li = li->next, column_idx++) {
+    /* work around the yalign = 0.0 gtk uses */
+    if (item_orientation == GTK_ORIENTATION_HORIZONTAL) {
+      g_object_set (li->data, "yalign", 0.5, NULL);
     }
+
+    /* do not wrap when text beside icons is enabled */
+    if (column_idx == text_column_idx) {
+      g_object_set (li->data, "ellipsize",
+                    item_orientation == GTK_ORIENTATION_HORIZONTAL ?
+                    PANGO_ELLIPSIZE_END : PANGO_ELLIPSIZE_NONE, NULL);
+    }
+  }
+  g_list_free (renderers);
 }
 
 
@@ -707,6 +713,7 @@ xfce_appfinder_window_view (XfceAppfinderWindow *window)
       gtk_icon_view_set_pixbuf_column (GTK_ICON_VIEW (view), XFCE_APPFINDER_MODEL_COLUMN_ICON);
       gtk_icon_view_set_text_column (GTK_ICON_VIEW (view), XFCE_APPFINDER_MODEL_COLUMN_TITLE);
       gtk_icon_view_set_tooltip_column (GTK_ICON_VIEW (view), XFCE_APPFINDER_MODEL_COLUMN_TOOLTIP);
+      gtk_icon_view_set_row_spacing (GTK_ICON_VIEW (view), 0);
       xfce_appfinder_window_set_item_width (window);
 
       g_signal_connect_swapped (G_OBJECT (view), "selection-changed",
@@ -1665,11 +1672,16 @@ xfce_appfinder_window_item_visible (GtkTreeModel *model,
 {
   XfceAppfinderWindow *window = XFCE_APPFINDER_WINDOW (data);
   /* don't use the casefolded key generated by gtk */
-  const gchar *filter_string= gtk_entry_get_text (GTK_ENTRY (window->entry));
+  const gchar *filter_string = gtk_entry_get_text (GTK_ENTRY (window->entry));
+  gchar *filter_string_down = g_ascii_strdown (filter_string, -1);
 
-  return xfce_appfinder_model_get_visible (XFCE_APPFINDER_MODEL (model), iter,
+  gboolean res = xfce_appfinder_model_get_visible (XFCE_APPFINDER_MODEL (model), iter,
                                            window->filter_category,
-                                           filter_string);
+                                           filter_string_down);
+
+  g_free(filter_string_down);
+
+  return res;
 }
 
 
@@ -1884,7 +1896,6 @@ xfce_appfinder_window_set_expanded (XfceAppfinderWindow *window,
 {
   GdkGeometry         hints;
   gint                width;
-  GtkWidget          *parent;
   GtkEntryCompletion *completion;
 
   APPFINDER_DEBUG ("set expand = %s", expanded ? "true" : "false");
@@ -1906,19 +1917,8 @@ xfce_appfinder_window_set_expanded (XfceAppfinderWindow *window,
       gtk_window_set_geometry_hints (GTK_WINDOW (window), NULL, &hints, GDK_HINT_MAX_SIZE);
     }
 
-  /* repack the button box */
-  g_object_ref (G_OBJECT (window->bbox));
-  parent = gtk_widget_get_parent (window->bbox);
-  if (parent != NULL)
-    gtk_container_remove (GTK_CONTAINER (parent), window->bbox);
-  if (expanded)
-    gtk_container_add (GTK_CONTAINER (window->bin_expanded), window->bbox);
-  else
-    gtk_container_add (GTK_CONTAINER (window->bin_collapsed), window->bbox);
-  gtk_widget_set_visible (window->bin_expanded, expanded);
-  gtk_widget_set_visible (window->bin_collapsed, !expanded);
+  /* show/hide preferences button */
   gtk_widget_set_visible (window->button_preferences, expanded);
-  g_object_unref (G_OBJECT (window->bbox));
 
   /* show/hide pane with treeviews */
   gtk_widget_set_visible (window->paned, expanded);
